# wrdcld
A predictable, interpretable wordcloud library

## Setup
Run `poetry install`

## Development
Run `poetry run isort wrdcld tests`, `poetry run black wrdcld tests` and `poetry run pylint wrdcld tests` for styling and linting.

## Testing
Run `python -m unittest discover tests/`
